@@ -37,7 +37,6 @@ class CfnParseError(ConstructorError):
     """
 
     def __init__(self, filename, errors):
-
         if isinstance(errors, cfnlint.rules.Match):
             errors = [errors]
 
@@ -78,7 +77,6 @@ class NodeConstructor(SafeConstructor):
     # construction") by first exhausting iterators, then yielding
     # copies.
     def construct_yaml_map(self, node):
-
         # Check for duplicate keys on the current level, this is not desirable
         # because a dict does not support this. It overwrites it with the last
         # occurance, which can give unexpected results
@@ -173,6 +171,7 @@ NodeConstructor.add_constructor(  # type: ignore
     "tag:yaml.org,2002:seq", NodeConstructor.construct_yaml_seq
 )
 
+
 # pylint: disable=too-many-ancestors
 class MarkedLoader(Reader, Scanner, Parser, Composer, NodeConstructor, Resolver):
     """
@@ -193,6 +192,18 @@ class MarkedLoader(Reader, Scanner, Parser, Composer, NodeConstructor, Resolver)
         Resolver.__init__(self)
         NodeConstructor.__init__(self, filename)
 
+    def construct_getatt(self, node):
+        """
+        Reconstruct !GetAtt into a list
+        """
+
+        if isinstance(node.value, (str)):
+            return list_node(node.value.split(".", 1), node.start_mark, node.end_mark)
+        if isinstance(node.value, list):
+            return [self.construct_object(child, deep=False) for child in node.value]
+
+        raise ValueError(f"Unexpected node type: {type(node.value)}")
+
 
 def multi_constructor(loader, tag_suffix, node):
     """
@@ -204,7 +215,7 @@ def multi_constructor(loader, tag_suffix, node):
 
     constructor = None
     if tag_suffix == "Fn::GetAtt":
-        constructor = construct_getatt
+        constructor = loader.construct_getatt
     elif isinstance(node, ScalarNode):
         constructor = loader.construct_scalar
     elif isinstance(node, SequenceNode):
@@ -220,19 +231,6 @@ def multi_constructor(loader, tag_suffix, node):
     return dict_node({tag_suffix: constructor(node)}, node.start_mark, node.end_mark)
 
 
-def construct_getatt(node):
-    """
-    Reconstruct !GetAtt into a list
-    """
-
-    if isinstance(node.value, (str)):
-        return list_node(node.value.split(".", 1), node.start_mark, node.end_mark)
-    if isinstance(node.value, list):
-        return list_node([s.value for s in node.value], node.start_mark, node.end_mark)
-
-    raise ValueError(f"Unexpected node type: {type(node.value)}")
-
-
 def loads(yaml_string, fname=None):
     """
     Load the given YAML string
